@@ -143,7 +143,7 @@ def Trajectory(data,bodyPartTraj,bodyPartBox, **kwargs):
         plt.yticks(fontsize = fontsize*0.8)
         plt.show()
 
-        if type(saveName) == type(None):
+        if type(saveName) != type(None):
             plt.savefig(saveName+figformat)
 
     else:
@@ -481,7 +481,7 @@ def FieldDetermination(Fields,plot=False,**kwargs):
 
     values = (data.iloc[2:,1:].values).astype(np.float)
     lista1 = (data.iloc[0][1:].values +" - " + data.iloc[1][1:].values).tolist()
-    null = .001
+    null = 0
     fields = pd.DataFrame(columns=['fields','center_x','center_y', 'radius', 'a_x', 'a_y' , 'height', 'width'])
     circle = []
     rect = []
